pro llsurf_to_xyz, ll, dtmr, r, xyz_out
;
; Convert the given longitude and latitude of a point on
; the surface to xyz. 
; 
; Interpolates between an array of radii to get a
; location on the surface of Bennu as represented
; by the DTM. 
;
; Input
;   ll[2] = longitude and latitude in degrees
;   dtmr= surface radius of the lat, lon locations. Regular grid,
;     -180 to 180 longitude.
;   
; Output
;   r= surface radius of this lontitude and latitude
;   xyz_out[3]=  xyz for the input latitude and longitude
; 
; Created October 2019, Perry
;
;

; Convert to negative longitude, if necessary
if ll[0] ge 180. then ln= ll[0] - 360. else ln= ll[0]

; Convert longitude and latitude from degrees to radians
lonr= ln/!radeg
latr= ll[1]/!radeg

; Get size of dtm
sdtm= size(dtmr)

; Calculate resolution of DTM
dtmres= 2.*!pi / float(sdtm[1]-1)

; Get fractional index locations of longitude and latitude
f_lon= (lonr+!pi)/ dtmres
f_lat= latr/ dtmres

; Interpolate to find  radius at this lon, lat.
r= interpolate(dtmr, f_lon, f_lat)

; Create output array
xyz_out= fltarr(3)

; Calculate and store xyz
xyz_out[0]= r * cos(latr) * cos(lonr)
xyz_out[1]= r * cos(latr) * sin(lonr)
xyz_out[2]= r * sin(latr)

;stop,'check llsurf'

return
end